@@ -2,32 +2,9 @@
     utils/classify.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "classify.h"
@@ -100,7 +77,7 @@ static const unsigned int defaultClassification = NoClass;
 
 template <template <typename U> class Op>
 struct ByExtension {
-    typedef bool result_type;
+    using result_type = bool;
 
     template <typename T>
     bool operator()(const T &lhs, const T &rhs) const
@@ -139,7 +116,7 @@ static const struct _content_classification {
 
 template <template <typename U> class Op>
 struct ByContent {
-    typedef bool result_type;
+    using result_type = bool;
 
     const unsigned int N;
     explicit ByContent(unsigned int n) : N(n) {}
@@ -324,7 +301,7 @@ QString Kleo::printableClassification(unsigned int classification)
     if (classification & CertificateRequest) {
         parts.push_back(QStringLiteral("CertificateRequest"));
     }
-    return parts.join(QStringLiteral(", "));
+    return parts.join(QLatin1String(", "));
 }
 
 static QString chopped(QString s, unsigned int n)
@@ -347,7 +324,7 @@ QString Kleo::findSignedData(const QString &signatureFileName)
 }
 
 /*!
-  \return all (existing) candiate signature files for \a signedDataFileName
+  \return all (existing) candidate signature files for \a signedDataFileName
 
   Note that there can very well be more than one such file, e.g. if
   the same data file was signed by both CMS and OpenPGP certificates.
@@ -357,9 +334,9 @@ QStringList Kleo::findSignatures(const QString &signedDataFileName)
     QStringList result;
     for (unsigned int i = 0, end = sizeof(classifications) / sizeof(_classification); i < end; ++i)
         if (classifications[i].classification & DetachedSignature) {
-            const QString candiate = signedDataFileName + QLatin1Char('.') + QLatin1String(classifications[i].extension);
-            if (QFile::exists(candiate)) {
-                result.push_back(candiate);
+            const QString candidate = signedDataFileName + QLatin1Char('.') + QLatin1String(classifications[i].extension);
+            if (QFile::exists(candidate)) {
+                result.push_back(candidate);
             }
         }
     return result;
